@@ -11,8 +11,9 @@
 #include "icalformat.h"
 #include "memorycalendar.h"
 
-#include <DHiDPIHelper>
+
 #include <DStyle>
+#include <DIcon>
 #include <DIconButton>
 #include <QToolTip>
 #include <QPainter>
@@ -149,12 +150,12 @@ bool JobTypeListView::viewportEvent(QEvent *event)
                         return true;
                     }
                     auto actionEdit = new DViewItemAction(Qt::AlignVCenter, QSize(20, 20), QSize(20, 20), true);
-                    actionEdit->setIcon(DHiDPIHelper::loadNxPixmap(":/icons/deepin/builtin/icons/dde_calendar_edit_32px.svg"));
+                    actionEdit->setIcon(DIcon::loadNxPixmap(":/icons/deepin/builtin/icons/dde_calendar_edit_32px.svg"));
                     actionEdit->setParent(this);
                     connect(actionEdit, &QAction::triggered, this, &JobTypeListView::slotUpdateJobType);
 
                     auto actionDelete = new DViewItemAction(Qt::AlignVCenter, QSize(20, 20), QSize(20, 20), true);
-                    actionDelete->setIcon(DHiDPIHelper::loadNxPixmap(":/icons/deepin/builtin/icons/dde_calendar_delete_32px.svg"));
+                    actionDelete->setIcon(DIcon::loadNxPixmap(":/icons/deepin/builtin/icons/dde_calendar_delete_32px.svg"));
                     actionDelete->setParent(this);
                     connect(actionDelete, &QAction::triggered, this, &JobTypeListView::slotDeleteJobType);
 
@@ -226,7 +227,6 @@ void JobTypeListView::slotImportScheduleType()
     KCalendarCore::ICalFormat icalformat;
     QTimeZone timezone = QDateTime::currentDateTime().timeZone();
     KCalendarCore::MemoryCalendar::Ptr cal(new KCalendarCore::MemoryCalendar(timezone));
-    auto ok = icalformat.load(cal, filename);
     auto typeID = cal->nonKDECustomProperty("X-DDE-CALENDAR-TYPE-ID");
     auto typeName = cal->nonKDECustomProperty("X-DDE-CALENDAR-TYPE-NAME");
     auto typeColor = cal->nonKDECustomProperty("X-DDE-CALENDAR-TYPE-COLOR");
@@ -453,7 +453,7 @@ void JobTypeListViewStyle::paint(QPainter *painter, const QStyleOptionViewItem &
     // 获取当前字体的信息
     QFontMetrics fontMetrics(opt.font);
     // 当前文字长度是否大于显示框长度
-    if (fontMetrics.width(displayName) > (opt.rect.width() - 90)) {
+    if (fontMetrics.horizontalAdvance(displayName) > (opt.rect.width() - 90)) {
         displayName = fontMetrics.elidedText(displayName, Qt::ElideRight, opt.rect.width() - 90); // 截取字符串长度用...代替
     }
     if (view && view->m_iIndexCurrentHover == index.row()) {
